package com.chelvc.framework.wechat;

/**
 * 微信小程序操作接口
 *
 * @author Woody
 * @date 2024/6/19
 */
public interface WechatAppletHandler {
    /**
     * 获取应用名称
     *
     * @return 应用名称
     */
    String getName();

    /**
     * 获取应用标识
     *
     * @return 应用标识
     */
    String getAppid();

    /**
     * 获取小程序Scheme码
     *
     * @return 小程序Scheme码
     */
    default String getScheme() {
        return this.getScheme(null, null, null);
    }

    /**
     * 获取小程序Scheme码
     *
     * @param path        进入的小程序页面路径
     * @param query       进入小程序时的 query
     * @param environment 环境标识（正式版为"release"，体验版为"trial"，开发版为"develop"）
     * @return 小程序Scheme码
     */
    String getScheme(String path, String query, String environment);

    /**
     * 获取小程序二维码
     *
     * @param page  页面路径
     * @param scene 场景信息
     * @return 二维码图片base64编码
     */
    default String getQrcode(String page, String scene) {
        return this.getQrcode(page, scene, false);
    }

    /**
     * 获取小程序二维码
     *
     * @param page  页面路径
     * @param scene 场景信息
     * @param width 二维码宽度
     * @return 二维码图片base64编码
     */
    default String getQrcode(String page, String scene, int width) {
        return this.getQrcode(page, scene, width, false);
    }

    /**
     * 获取小程序二维码
     *
     * @param page        页面路径
     * @param scene       场景信息
     * @param environment 环境标识（正式版为"release"，体验版为"trial"，开发版为"develop"）
     * @return 二维码图片base64编码
     */
    default String getQrcode(String page, String scene, String environment) {
        return this.getQrcode(page, scene, false, environment);
    }

    /**
     * 获取小程序二维码
     *
     * @param page        页面路径
     * @param scene       场景信息
     * @param transparent 是否透明
     * @return 二维码图片base64编码
     */
    default String getQrcode(String page, String scene, boolean transparent) {
        return this.getQrcode(page, scene, 430, transparent);
    }

    /**
     * 获取小程序二维码
     *
     * @param page        页面路径
     * @param scene       场景信息
     * @param width       二维码宽度
     * @param environment 环境标识（正式版为"release"，体验版为"trial"，开发版为"develop"）
     * @return 二维码图片base64编码
     */
    default String getQrcode(String page, String scene, int width, String environment) {
        return this.getQrcode(page, scene, width, false, environment);
    }

    /**
     * 获取小程序二维码
     *
     * @param page        页面路径
     * @param scene       场景信息
     * @param width       二维码宽度
     * @param transparent 是否透明
     * @return 二维码图片base64编码
     */
    default String getQrcode(String page, String scene, int width, boolean transparent) {
        return this.getQrcode(page, scene, width, transparent, "release");
    }

    /**
     * 获取小程序二维码
     *
     * @param page        页面路径
     * @param scene       场景信息
     * @param transparent 是否透明
     * @param environment 环境标识（正式版为"release"，体验版为"trial"，开发版为"develop"）
     * @return 二维码图片base64编码
     */
    default String getQrcode(String page, String scene, boolean transparent, String environment) {
        return this.getQrcode(page, scene, 430, transparent, environment);
    }

    /**
     * 获取小程序二维码
     *
     * @param page        页面路径
     * @param scene       场景信息
     * @param width       二维码宽度
     * @param transparent 是否透明
     * @param environment 环境标识（正式版为"release"，体验版为"trial"，开发版为"develop"）
     * @return 二维码图片base64编码
     */
    String getQrcode(String page, String scene, int width, boolean transparent, String environment);

    /**
     * 获取访问令牌
     *
     * @return 访问令牌
     */
    String getAccessToken();

    /**
     * 获取微信用户信息
     *
     * @param openid openid
     * @return 微信用户信息
     */
    WechatUser getUser(String openid);

    /**
     * 根据临时令牌获取手机号
     *
     * @param code 临时令牌
     * @return 手机号
     */
    String code2mobile(String code);

    /**
     * 根据临时令牌获取会话信息
     *
     * @param code 临时令牌
     * @return 会话信息
     */
    WechatSession code2session(String code);
}
